@@ -1,6 +1,6 @@
 package WWW::Google::CustomSearch::Params;
 
-$WWW::Google::CustomSearch::Params::VERSION = '0.18';
+$WWW::Google::CustomSearch::Params::VERSION = '0.19';
 
 use 5.006;
 use strict; use warnings;
@@ -18,7 +18,7 @@ WWW::Google::CustomSearch::Params - Placeholders for parameters for WWW::Google:
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
@@ -219,6 +219,10 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 L<https://github.com/Manwar/WWW-Google-CustomSearch>
 
+=head1 CONTRIBUTORS
+
+David-Kitcher Jones (m4ddav3)
+
 =head1 BUGS
 
 Please  report  any  bugs or feature requests to C<bug-www-google-customsearch at
