@@ -1,6 +1,6 @@
 package WWW::Google::CustomSearch::Result;
 
-$WWW::Google::CustomSearch::Result::VERSION = '0.18';
+$WWW::Google::CustomSearch::Result::VERSION = '0.19';
 
 use 5.006;
 use Data::Dumper;
@@ -17,7 +17,7 @@ WWW::Google::CustomSearch::Result - Placeholder for Google JSON/Atom Custom Sear
 
 =head1 VERSION
 
-Version 0.18
+Version 0.19
 
 =cut
 
@@ -228,6 +228,10 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 L<https://github.com/Manwar/WWW-Google-CustomSearch>
 
+=head1 CONTRIBUTORS
+
+David-Kitcher Jones (m4ddav3)
+
 =head1 BUGS
 
 Please report  any  bugs  or feature requests to C<bug-www-google-customsearch at
